#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bower-json
version:              1.1.0.0
visibility:           public
id:                   bower-json-1.1.0.0-AZN1smoIuLZEwQuVoykbCp
key:                  bower-json-1.1.0.0-AZN1smoIuLZEwQuVoykbCp
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/bower-json
synopsis:             Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.

category:             Web
abi:                  0448bb235b8b74f61da119b50c261d20
exposed:              True
exposed-modules:      Web.Bower.PackageMeta
hidden-modules:       Web.Bower.PackageMeta.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/bower-json-1.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bower-json-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bower-json-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bower-json
hs-libraries:         HSbower-json-1.1.0.0-AZN1smoIuLZEwQuVoykbCp
depends:
    aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V
    aeson-better-errors-0.9.1.4-DDzOjBl4RZmIIXGFWYaF9I base-4.18.2.1
    bytestring-0.11.5.3 deepseq-1.4.8.1 ghc-prim-0.10.0 mtl-2.3.1
    scientific-0.3.8.1-6O6hUkglHhJ388M1FqOkp1 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp
    vector-0.13.2.0-5a59Ladt6HH20irTaXAFu7

haddock-interfaces:   /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html:         /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

